package com.yeejoin.amos.api.householdapi.face.service;

public interface GoodWeDataAcquisitionService {
    /**
     * @descrption 场站列表数据入库
     */
    void stationList();
    /**
     * @descrption 场站详情数据入库
     */
    void stationDetail();

    void stationMonthGen();
    void stationYearGen();
    /**
     * @descrption 采集器列表数据入库
     */
    void collectorList();
    /**
     * @descrption 采集器详情数据入库
     */
    void collectorDetail();
    /**
     * @descrption 逆变器列表数据入库
     */
    void inverterList();
    /**
     * @descrption 逆变器详情数据入库
     */
    void inverterDetail();

    void inverterMonthGen();

    void inverterYearGen();
    /**
     * @descrption 采集器告警列表数据入库
     */
    void inverAlramInfo(String stationid);
}
